@@ -348,14 +348,12 @@ class DataStream:
         self.operator.aggr_func('Sum', on=on, name=name)
         return self
 
-    def count(self, on="", name=""):
+    def count(self, name=""):
         """
         Aggregation function count for the window.
 
         Parameters
         ----------
-        on : str
-             On which attribute to count.
         name : str, optional
                How to call the column.
 
@@ -368,11 +366,11 @@ class DataStream:
         >>> c = nes.Connection("127.0.0.1", 8081)
         >>> cars = c.get_logical_stream("cars")
         >>>
-        >>> cars.sliding(on="color", size=10, size_unit="sec", slide=5, slide_unit="sec").max(on="color", name="")
+        >>> cars.sliding(on="color", size=10, size_unit="sec", slide=5, slide_unit="sec").max(name="")
 
 
         """
-        self.operator.aggr_func('Count', on=on, name=name)
+        self.operator.aggr_func('Count', on="", name=name)
         return self
 
     def avg(self, on="", name=""):
@@ -399,8 +397,9 @@ class DataStream:
 
 
         """
-        self.operator.aggr_func('Avg', on=on, name=name)
-        return self
+        # self.operator.aggr_func('Avg', on=on, name=name)
+        # return self
+        raise NotSupportedError("NebulaStream does not support average at the moment!")
 
     def min(self, on="", name=""):
         """
@@ -696,9 +695,6 @@ class DataStream:
 
         no_of_elements_arriving = 0
 
-        counting = 0
-        print(counting)
-
         while self.running:
             try:
                 timeout = dict(poller.poll(self.timeout))
@@ -749,8 +745,6 @@ class DataStream:
                         for i in range(rows):
                             one_row_byte = message[i * bytes_per_row:(i + 1) * bytes_per_row]
                             data, dictionary = _byte_row_to_string(details, one_row_byte, list(details_dict.keys()))
-                            counting += 1
-                            print(counting)
                             if batch_mode:
                                 # adding to batch buffer and assuming order variables don't change
                                 batch_buffer = batch_buffer.append(dictionary, ignore_index=True)
@@ -797,7 +791,6 @@ class DataStream:
         if stringio is not None:
             return stringio.getvalue()
         elif batch_mode:
-            print(f"result: {counting}")
             return batch_result
 
     def _process_in_batches_with_dataframe(self, batch_function, data_frame, batch_result):
